# Gestational Limits
| State | Banned After Weeks Since Last Menstrual Period | Life Exception | Health Exception | Fetal Health Exception | Rape or Incest Exception | Last Updated |
| ----- | ---------------------------------------------- | -------------- | ---------------- | ---------------------- | ------------------------ | ------------ |
| Alabama | 0 | True | Physical | No exception | No exception | 2022-06-28T22:14:05.000Z |
| Arizona | 99 | True | Any | No exception | No exception | 2022-06-30T13:26:49.000Z |
| Arkansas | 0 | True | No exception | No exception | No exception | 2022-06-24T18:39:14.000Z |
| California | 99 | True | Any | No exception | No exception | No date available |
| Connecticut | 99 | True | Any | No exception | No exception | No date available |
| Delaware | 99 | True | Any | Lethal fetal anomaly | No exception | No date available |
| District of Columbia | 99 | True | Any | No exception | No exception | No date available |
| Florida | 15 | True | Physical | Lethal fetal anomaly | No exception | 2022-07-05T15:55:49.000Z |
| Georgia | 22 | True | Physical | Lethal fetal anomaly | No exception | No date available |
| Hawaii | 99 | True | Any | No exception | No exception | No date available |
| Idaho | 99 | True | No exception | No exception | No exception | No date available |
| Illinois | 99 | True | Any | No exception | No exception | No date available |
| Indiana | 22 | True | Physical | No exception | No exception | No date available |
| Iowa | 22 | True | Physical | No exception | No exception | No date available |
| Kansas | 22 | True | Physical | No exception | No exception | No date available |
| Kentucky | 22 | True | Physical | No exception | No exception | 2022-06-30T14:01:14.000Z |
| Louisiana | 22 | True | Physical | Lethal fetal anomaly | No exception | 2022-06-27T18:06:17.000Z |
| Maine | 99 | True | Any | No exception | No exception | No date available |
| Maryland | 99 | True | Any | Serious fetal anomaly | No exception | No date available |
| Massachusetts | 24 | True | Any | Lethal fetal anomaly | No exception | 2022-06-30T09:58:24.000Z |
| Michigan | 99 | True | No exception | No exception | No exception | No date available |
| Minnesota | 99 | True | Any | No exception | No exception | No date available |
| Mississippi | 20 | True | Major Bodily Function | Serious fetal anomaly | No exception | 2022-06-27T13:29:59.000Z |
| Missouri | 0 | True | Physical | No exception | No exception | 2022-06-24T15:19:57.000Z |
| Montana | 99 | True | Major Bodily Function | No exception | No exception | No date available |
| Nebraska | 22 | True | Physical | No exception | No exception | No date available |
| Nevada | 24 | True | Any | No exception | No exception | No date available |
| New Hampshire | 24 | True | Physical | No exception | No exception | 2022-02-11T15:50:11.000Z |
| New York | 99 | True | Any | No exception | No exception | No date available |
| North Carolina | 99 | True | Any | No exception | No exception | 2019-11-13T12:12:09.000Z |
| North Dakota | 22 | True | Physical | No exception | No exception | No date available |
| Ohio | 6 | True | Physical | No exception | No exception | 2022-06-24T22:39:26.000Z |
| Oklahoma | 0 | True | No exception | No exception | No exception | 2022-06-24T18:35:26.000Z |
| Pennsylvania | 24 | True | Major Bodily Function | No exception | No exception | No date available |
| Rhode Island | 99 | True | No exception | No exception | No exception | 2019-07-02T11:33:41.000Z |
| South Carolina | 6 | True | Physical | Lethal fetal anomaly | True | 2022-06-27T22:30:55.000Z |
| South Dakota | 0 | True | No exception | No exception | No exception | 2022-06-24T14:47:55.000Z |
| Tennessee | 6 | True | Physical | No exception | No exception | 2022-06-28T16:54:23.000Z |
| Texas | 0 | True | No exception | No exception | No exception | 2022-07-02T10:05:28.000Z |
| Utah | 18 | True | Major Bodily Function | Lethal fetal anomaly | True | 2022-07-01T19:52:54.000Z |
| Virginia | 26 | True | Any | No exception | No exception | 2022-02-15T21:04:54.000Z |
| Washington | 99 | True | Any | No exception | No exception | No date available |
| West Virginia | 22 | True | Physical | Lethal fetal anomaly | No exception | No date available |
| Wisconsin | 22 | True | Major Bodily Function | No exception | No exception | No date available |
| Wyoming | 99 | True | Any | No exception | No exception | No date available |